// Copyright 2023 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROMEOS_ASH_COMPONENTS_CARRIER_LOCK_PSM_CLAIM_VERIFIER_UNITTEST_H_
#define CHROMEOS_ASH_COMPONENTS_CARRIER_LOCK_PSM_CLAIM_VERIFIER_UNITTEST_H_

namespace {

const char kResponseOprf[] =
    "CkYKIQIaWHGulrkrwhlzPZsBa0E/mSzh0Ri1TWafLHQJvT29bRIhAufw2IQ8trz1bN4aS6uqBx"
    "w2wFghI921r177QLR/qx8JEgAaBAgKEAEiGAoICIGA/////wMKBAiBgGEQChgEIAgoAg==";

const char kResponseQuery[] =
    "CtE/CiECGlhxrpa5K8IZcz2bAWtBP5ks4dEYtU1mnyx0Cb09vW0Sqz8Kpj8KhhUKgBWAsY+nnN"
    "WVXFqQl6lhX9rZlq+rIW+CSjLRNhl7LTDJB7f8fBnkY/cj9aFtr5AOFhz1m7qD2sFiTe/b7A2Z"
    "xnAPWbHLdJCRWafspgS07I/QGN/yTVSNMjJhf/TcONYEN6V1AfQPGEJFQl2VW86RB0TpXN3+oX"
    "QT11KNPBZMyRY10yhFWNqN0b2dgSqmQHEIpIlQfBOEoCSIO1bmzSRKAsVeHw7hAP2a+wH25Lfx"
    "WAQPtXWoVroWGCnwucgsdy0WL+uLfHUwChsGA1Lj+JqShQdGOVp/i3Dqw4Jjj3+dKqxeb3LtYv"
    "YLzZjVTW5wDa3qm+a5sMzUCmXfNr86GonviKUJRUpziB8e6sypwgHlrNFx2SCLCeh3dsXW3d2/"
    "o4GF0lyDL3YQFLxXcOkhndHgUEP8C891tLDhaahR+Ht71QFvVr3+QDalg4LLclpLJnYpJSLb6M"
    "iXmcgxoyULvGGDXcli7W5FO3uHU6Ck7dwbBtJPtuRyd58b0/ocAwA5HCorUZzSk5iRI/ebMJma"
    "O15qlk5u7E4h6G1ds6rbgZBX4DlnjhgJ6b4SP3OwqpBYQ7GiMaxlJV4uSkawvGvABIqokaa+Ko"
    "jzye587/woyjaKSD3LmGXAo+ZzmF44Vc8Ph1XuonmxygeFwU0LNqVQAwfUmlt512yhciGR6xqM"
    "NYVYYk1imqWPZQkaBYqCpDX0KIu5edewViTdttQ92B+QymGAH6TYTE6U0EAkWcjLUXur52hmSt"
    "8Yhu0YBCro0/OIrlzzNxuv08Jn+Zfhbdq16por9jGmfmY0HhMfyM26DLMcYgNdgZGvnnAgalGc"
    "G1BxYD9MFmeEUKjqiBEtmCf3oTJFSBa5g50vZJRNm+MdYIZZidQDbjg/kHYpNslmGRqMwROrik"
    "fzOUA4auyLHYGaoppdC4IO6kmg90P4RrCAMywFxjh3AR144Afmr5pVVRB8bVRzSq3YWbj/4Va6"
    "zK9IL79Iil4HYlfM58XPTmAduNQ03T8N7CFtiqz52cVMDVZhWJJNlsQxQRjWaxeKl7aexfEnCX"
    "0Cm3T957lpefnZKADmWUWkZE+Lio59zD+XsXWgNJ7KNMhQEm6xMIzhKlJjjmCOpPt8/3ifUHwt"
    "gazESu1kWf4+QJUmphuqknEnnS+bZyH64azTscoUEBumltymBE4pEKOB6lTwSC2P9KUUNN8hRG"
    "XAsBpDV9LbBK467EpvEsrdhbr9xoszru0tIgBiIlGh+fXirHRMI31MUiq5noFu96TCalmP0Q4A"
    "8NRlTO9HFywy4b6AIfax3KkosQu+B6tnWlSeEbODr1GQQdHYlHUwsEtGygRQSbIzxFF7UfPfC+"
    "nieYp5ZBOKhu5O089HMYJAs9VaNM1AwiVwzeK+ASqMoxlVgKtzVRzWrNPkCCgPOY4pQm5TGjRc"
    "03hfLrtW9j/txJwsi2djsKmOu+9tE+EVqEVhF5M8EEbV1UWiVXYkimULvO4tOyuve4bzR1HSc0"
    "+vK/ikgRcviE0GUZedFn3kIHXYj8LZrlVBWyLmI2Rh74xf4rHK4QmGBvc2jj7UANx0KIa9SK+Q"
    "lRwa94L7cC/3JKwMxS0R42oHS96nFZDJBGHuAIyc+4hCgdXdQu7gdF1WTkcsvioQGycEpEU5FG"
    "mr5HEpEy5vAb/DW5L6xA2IAUNbC9cDMf+VYFBa4Z61/6w5z8X5LhwsRiMHWXRyHhkBTu1V2kcK"
    "nkdaOmTXWbWGsZ4S6/SNWHG7Wrf6L865cBmTR8bDNsHQpAcdU1VBQ1ckqE40uQGlWWR3tfAv5A"
    "4jv2M59q8Zi6s/sonbJzWtSPpuu7JZV9tdaJ+WgdBxo4zSmD63tM8w+ODXitgIuScK/VURHCQj"
    "MRsGQc2RTF1U8EZSI4IHxIeJCdblUbautjeoqHcDv9wVyD/g7lQ48i6GLQm8si2D3IXi1JnRkG"
    "E+Xm2gPVz/hUrygaHCUJaKjfZYdTYpdpD2yZ2/KnnOpslMi3yT247hK3I8U+UhyL5VMQqKRpZS"
    "Gsnevcqr1ViOgRDLcC1pBzHYuP2+HBVjT4ZaDEf9qtSQQV5Hrn7cI/PD3gzTNfOwFnzclon/U0"
    "gUTfGvwe45a0UBd8zB5quxCiEoiuD/Eq3apc4zlOBGRyZFd2SPCJQaxA4ozr48RT/fZL7bSmCU"
    "NTfgYgRiK4q0uR8jOUwfmG7RLEMqd2I6YAMjQZqNiGUxgo/2VA4suiSUBZuXw4roTKmWzAj+FB"
    "tSLNMnL0hC3IaxLLYbuJ482GXiovIRpuPLrr1TGlSlchT1hjqk2pB5NEnpwFOshKz9Y7dUOOAO"
    "zh0ow9brR6Bn4oXKFijZn1RFuWar2A3BOmy+V6gjCuAlw2s84jQ5o1VHkuAjVzC0sn39EjrtHZ"
    "sZL3mLCK31H+EyQkPkBKtFnDWW5kjslSNUbQOKBb4hBx81++NCllLmqqBy74VBU5X9lQneu3Sc"
    "KE3W9ixUeqz5SwcoUWPQBw/dEvNfN44nKB5LdCu7478hcmVp22muqcHdtMsEHrADFKxMqTvl9q"
    "29//DrvjUblYJUtyOufA59Gh1iHa9I4lYRLaWD4hLfEEFa+BwBVQghuXQnLz7bJczm4X6GNmTN"
    "WviTiiyNsq5fFnRCPW8KSRFbiaPMLIao5EuEWLJ0JOiimFzXB3kky02NLlj7KWiHl4L6aHEJ0U"
    "4SttIYMCjLWN8YyjMHMterMYx1I5WCsK0oQeTLHXUFnidbuch0ckUAHt0rWcmDbpruhXIEh0y0"
    "zi6/rmhVTVK0yo0RpGjcpkJwbzo2til8bYA5xEA4aNosD08ALNQ9EWGhX7Vl38A3XoVP1xrf1p"
    "OpqcxjTZwGPCG8zvXEm6swIbf20rZciF36978wt6TkNTphpjxSd0oGXuZa+9/Z4AaB2QG3D/Zd"
    "OLIXLFN35UvFTbj0FREfYmsN3NVeCGpsevGQFAQHYGAzjQ5mq4JK/DJ7Csx7SG+Y4liOUtWyIh"
    "xBY7YSx6oww6Rx1DXjIDLlRRKrDK3ba6dVAeKZE6G8sIX6kuYnfympYn2L6MhEsErEgpIUBDdA"
    "3aXgFbBVaISbhcg8Wm2nS+lkBSU62lbOW29tApKI6QESlhK9mQqSQw5kO/+GJqro8Am981YbdF"
    "LlVSifQg5fpldm6QT0zqWa20NhbZmyF3MVNlcabDySGIrTkb713EFCwerlGJO85yv+mg6qPPei"
    "2piycsZ+9EBGmwWoyi089HwsF/JImzI2d/e7dExAuM/7VEVkymTrvQeKKWp1EA5adZBLnl84s8"
    "NqVzKbbG+hJL8cBstMANM+1mRqSJ5KjVPpRFu5rqZtpjOOSqqviJmACB4RWShH8prjdje55FF1"
    "juGqyJORyjm+MJ+KZ0pMYZIkw0xj+nyQXcsuaLnemlKu8V7CEG3NGQX/BX+xgsqstSZ+lXAKjm"
    "5Tcl/mt2ahZW47ghdZBxltw6oVyzcUoDh71QEZ/a0wMoxeEQ5R4Lfi59cKoDS5lkq5cjSSD/RN"
    "yYrz4LSM1YcD/ReJFkoYDIAXoPN9hQsu3PADm/NYRsAu+wHpH2K5gsU5ZnVQSXTVyAGaqqjBwy"
    "86WxwYmVOmayruKKUWstIpeWAQgAgKhhUKgBXNDybJIDZ03F5C6nB/liNm2IrUPm6kx8CnTz2p"
    "y738Ql1H3Kmjp7Zxp02wKYT38qW1CYS1FDg4vyWZ4PhR2ST60dV6+H4Jn8XjBMtziwpSEEr1DJ"
    "D8ys1C3u6zGfzBysezJsISBd74vTsaJybmH06BSZ+OdVe2bHTngJ9zdcCXNBI/2q65xWh3g5al"
    "Gm1HPWSRYy12H2oOc4RwXSKDdfSqCMzXlosiQQ7s2DDI6ugqMx7nk5ISRpKrnatJujw81RONc5"
    "ah3vN9i0PcOq6jvSbRnqeaBdI1ov0wImNyhrWQLEICgawlvVDYFWVnYGQtVOoIBi054ywX17sT"
    "kHCk4FPq34kChcO5CPeW+DQgEroFhlQbvtY/3kVMvyY+ZPYNqLjBtu/hI0Y2oXeeTboXMhq5Uf"
    "KQnM3d2ZZ05idIhIBwGY3VMQ0Cla41fD4lnUn546Gpkg2Pgg4iOi4xShKIUinmDb08oaQdGFKD"
    "jGT5PxeT4g/IPmIGjhEi1rzjK+3lnninpRBS9toz64btHgn2Yk6iAK99OimSUg6+GkhQ0E2A9i"
    "ZRcUzr7AA8rgxzLhGzhEMjvfPhwdA14mWlOtSwVbTZLaAbUcrJtoYhb7p89KL/jkz6d9lvHhcE"
    "Wor+9tnJZQqiHBjYt4yRn8yGmDv+EcTl8GyQymVVoFhSQ8ctDqBbRTDvcSkyIVKTrzrA9RtAEy"
    "alAsT3TvIpdOgE0J7hJ00D5S0G+QMttOTtKKiMaXu17pvZzeGtN7kH3OucqXE42RqOVKUHfmpF"
    "BRhF9jK68uVs9YUiBAnYak7X+htCA8ioWpU+b6yCD1HRG1FxIjlfj/TnpW3dO6zXF4Okmq1QSR"
    "KD1gZbnxGfim2Ngr9yX7QhyJA2VNOSs6VobBcGW510JAyIDrbPPLX2v7HypuYPQMMm9qJQQJtX"
    "LS8qkpRyUHXChP57MW1oXOzjlrJCJkpBJu5EH68CbI0PzU3DYlFLxrU9f/Jpq6gZV07B252u4r"
    "gVmVt59BEjsneZ5TXQTpa1W+FjTyMnEpAEDL3wUq+1oYKdhRBiCYw1QiFcW7XBxiIX5y22FqXY"
    "Oe33hToKKdZA+WYR53V7ZkduTUqFSnJPMo4U01ffNY5tmHj8BpcidrIk368xpNtmv0HR+atydS"
    "w+RMyRNTqs3BsqQXOf1NJH5qEllbu8/bc076FSC0cKwr1hYVuGPvGonrrq+vdkhflvl3baK1sC"
    "ZGqax3Ypo2Fb9bAf9QijxaXsa/Alde7thKYq56YnPRWMkD1Krh0LBM3rVl6d0X3ThDlsxOsbOl"
    "6cxc61awuzZpcQbpK47CTz6eUWPbB0p0NbEfES7z/FrhHcrQgRVMdTsgzoIbSF2Otp9imu2cqx"
    "t5ACgILnjErbwVm9Ggox0j6bpxek5h4x9qHFuohmXhtCCdm6Nj2BNBxxumU5LSiQVu7tItikEP"
    "OQrEzLU1T7fn0UxcdHG565oR8FYSqfnHDdmNgx5AT2gu3CIEKsVZV0NEjKPLEVHpthebhjA7P+"
    "aZR6yjbvQEiyOpkvagubU1vpCOcnveW91AEYaa8M7Ezvdxx8AzqAb6imNz1wYDkoekkuwD6McZ"
    "bkmnOdrKc4Ss2symeCxA0e4h8dUu96Q4+lueys4uW3yD4jEwNy3DVX8OBjV01lS8jx8mrMIUwo"
    "ZZUdIAGRJYHbnG0l7tSIsjnyJhONskqIklxmJ8HY8ayj8W8pLcUJvdmucSTe9p8OQY2JSlRWt9"
    "JClDD4rJCgJ7FgQjAjYJB7bF4yvlJOBmSNwfUxCWnbYoXTp5vBKQGpCPRySmA72dVc44O2QivP"
    "cFcbpGmPz6UJUxJzrzfqt8Nv82eL5TpQ/nNby0IDK4b3QLzCJeYuIpofKlpJSDYa+SehcnQMop"
    "L/qfqVMllhDqT71gLLVq27PC28nIEbNRj1jhWBViItWxKypWpApySJQ+m2ojhH89NIxXtk/1IM"
    "wS4YxfSyOApo4hUHVQQNdxMkeqtv1avWKM30Dg8qe76Kxn1VK2pUoq+cTbYNcJVxvOAnZHcsup"
    "rOfaEjT7UH7dfuiB2LlX0N64fOwt8BMU85aVPqgaHeW71aC6FzaiBiYFvekQ9lOlWaQi4WVYJM"
    "g1e6NNvRUpwoqPVpRCMmTJJgAfjqNjzGpG1PeW4wvFLhNhZg8oZ5yuEmFwuq4n6hJFNmYmH7Kl"
    "b5G83U4O7Hr4BPxwpL9X1i/rfRUJ81OiGRYnRKrMctm31G9T3NnK70gL52cw1+D4U+3hmIQFk4"
    "hpOJDyU7eriH2moaAJ5rDsy+2G1mI3uc7h2QqoxNqS55ut2PA58JRBe1tCeF5L9dNo01u+ulgp"
    "msO9zkcI+AY+rS9qEo/3F4oktALZReApBFcCILp8iokW78lDof5ogQYj2pAkwXgANGJitnq+cQ"
    "6z0x6+bfRYWKm6B/eXhFacKgxe6q8kZk1QoOCVK5s4FPuqpCAo9n2TgChXIYqvD+OPa5VcHLlc"
    "LsDmUqE+Y9laxMzdUaYoEgrNBZNJJkJfgOkgc9HawOl+Jc1hWuC6/4uOgTDUMXHrmg3R4mEyht"
    "tlITs76EMe0TZW4Ue3Jg/Cu2eGmrI1XsjhjQOPzNCFSrKJXUGGZ/J+6TkuWTXWn2wUi++G2kRQ"
    "zkM01qYKDI5h4IvTCuGRF8uzIlkOsIZcFBiHLpHt6xUbBrsZBBNdCl4shN2rtw83NMl20cUAyU"
    "h3D+gsPX4xTBx68gc7elyjQACv8i43wi6oDiiweh0Vdcl45tJDhO4HcCgiGAmUuTCts62DFoBP"
    "Hn4sggPAJNOXWBc+4pLNHq1L6owYSW6fFPsjW9ZdI40CUFttoIpV8cQJcB9mgxmjtEA9hsQUqZ"
    "1FOwQLDtBgO4XkgPGrH2g3K2fjcu4+whuhd+y8rle0QQiwZxIxkl/rkEtiniUp4COeNyJMHHl8"
    "iUQ+NaVKmtqLCKcmgQf3cb43HzrTeVkDtAGiwt3hSksQF2tGPmNXAuu3mokXkm+rtkipmZ2kNu"
    "Y7SGyeVvD5zpmsFvW1GmmdUREw5GP1SnedXPOhYlOiqGAuLfEoVye1rF3HKkVXEehMrwIrt2ZO"
    "HQVEM8NijWrgTqQ8qZs0ImNRiIHnBR3YmNUhv6Egwun405lsW801mCvGUXsR4cwyJuDA45jEhs"
    "qjM16abjMtlp1OnFLLfzQMteURCqt5/XlqQaybJpyO0ZQYQnYMwIcC4eBKcBEC9/YN3B3v3zk2"
    "oP1ynpzy20IJIv6S0EuJfh0AFCT1gsWy9qQXSEGTgghrL+WrFfzfcdNXhPYy7q69VTDpQZA9H1"
    "qpjquhuTZmpLY4imxTVkUk6QaXKQPgyFcvvA/wgrKIzRDkHA0PzsVlm7EvSfF396VcFbhin8zv"
    "58Rhcr1jrOSqPbKXiYIXpUA2GYZ43hxJLMAco0oc7R+IHlkbItPAj1hviCnSYnUcUA+vZgnKcw"
    "lS+UBRTAsHX/LLjZOO+/vnHTzPx9o5/zcSfX1ZxtjhkO0Uns+JsfzL4cc6Sk44i4aQk2mzEbw5"
    "CB1hsnwTt1o5uHo3IH/YViRSl02fRAW35e4BCI8htGU4p6apSRs/SVkIvqFFEPzIEbDWoQgAgK"
    "hhUKgBXv/OHm4GZtvA6+6soF8k+BMv/yJKWHZK1tOonmmPR6qM4M+W3YXghWs1JMs8u4qaiuWs"
    "mawmClMApaCDtE7C87QY99+IYZWxc4Y0V+aRvB5xYoimB4a0Zt66D+HO4VIA2jwlGliJ9oK3pA"
    "WScT3d2vIzNY9eBa6B+sC2Rck5HR9vLocMrSH2yeZwx6E13Xlg5GBiXNopIjSTJGHEo5cVU7vW"
    "bo7ctUGW5bUaSbuen+SUXoIht+x94KgXpgeb+JXeOxdhlBHL6fe7iUNkOZIsTEqbXo+K64pqJ/"
    "yJDWxQ16+WdaaXfkNVhflkqUB4fsp0NWFYL07GQkay14z2fKkbVUaqCmTXGK0hzVSELN1CEkVp"
    "wtkUgDPnryXPUxmmcEloCviLkwzbW5ImDc7NwoHir8B/dQYopU9mNbmJs5ghXm2KKZgx3XYHo6"
    "cyyHduAhQlmcZmYrNY2DWiofBYIasibU50ZaGx8vevfQY/qaouTL2dUKMesG7v/dQU/H+IMmB6"
    "UXV72U0xE39VCjdG+ZswmT3ciXaH6GwuIbVZ8yzXcvxkMBdqeSIO6UoJkH2je+6QnFJGHOCEYK"
    "boo7626TIiFDz4eTkt6TXqjaTs0LQgKgU8qf2ib1EKvfY6S4tn6ReeKydjOKBZRkF/kVNNn8so"
    "h7LtdDf1HZsRaeqJb7V7ZHoyxqc1qwnsuUsKbb4SxpHVIAxUaX2UQ4GREBew/T75ct2m88c2FP"
    "LqJbFXv5mrvs2oHAoD7hRXQ7mLTtmgJ1l3hXktEpWS/SvHnDoLyXZtPR59jQvPY/SAsips7rKj"
    "WonpOHazQYgRDCsal80NgAqIUb4sIlyYkg3WcifjLX0uUBpUMuIG8f3cC55AQoqnMvApGiLd5j"
    "Zv5NbI1YwS4pVrjmzMuZrJ17jLB1w3fljsjEjjEqbqVAyYIEk0IkqSs/SWOGvvkNN8dzqpP31g"
    "2xIk5sDOUNBxJJaaznEXbgJguSFbAh5GyUgJU3tqIL5AJTF0ddPTVnTCMgN/rkrFt+JgIopUFn"
    "HlUx/CntDGUNH+z6Em3ShJ09Zf0kk3tSWEVVjK1GayTQAjBYJX7T7IZncxyTkVmOhAvlU6rpgX"
    "7FtNm2dqgiXnGYgW5drVaGuqLmygXb+xQkKFshG+eaz0ECF0QhNtKSvytvMW9ViCfem4A1UZNe"
    "LegC+NZAE5TTNiaiZEJfS1Hl2IaA1QFhIrmG3njchQbOzNrdfO919XipA+loNRzRSFtfxSsG1S"
    "tp2d+7GqUQJ5VmbHAdyAFPmCWVjtBtzwqaDIYb8RaOddF80e8ruHPeru0JNKP0d5pLe+VuHtlt"
    "BuJ4A8ZsBrlSzjJi77wwZzWjjO6CBRwr0+I5+zXaMdNrLXzgH1bndbSF2q+jZIBiBtVYqbKDD7"
    "uaYI0/KKZSW4i0h58BZYKvtzdRmRr7O4BJ+siVw+r69XIhf3hfTerVd69hbYvwxF2JPWmHCx7y"
    "YOqvM/+ZPYc0f3UsTEwrE73BiFJomObjDzW99jPNYOHv04DKQowE4ubsCDAYO0srT23xpNTJyX"
    "2lz/8RQq01omffH+odxhaHmWK0vljEz729e1sLS7uG57EdTXJ0o29wWJWGgwZA0G/YGJDe6Zqp"
    "gq098AsVpPjuPiIORC1KtMeuxUPFWDCgSqqyBcXtV4gd42k7tR7Ia6NhPIB3I0w0VyTxuDredv"
    "e85LaZdZvYCq6opoAkQBEUi9OcWEE1t6rcvVVkxpr5N4BFCYwj1vFsW0oeDq2dcdqb+1/Kb+E2"
    "AnS7Hwz/98MCeaOhTv8aIIOBh8mfHkhnDmLn8ISThgpZlrfbvsC/Qq1viZZKSEMhJe82VndePV"
    "YFGg0XXyfji3HzznxBVE0kKl2GOTgojig5GpQIKmh+lPXIaJU1O1ZKYEEZJmbIcDM5706mENWK"
    "as4pNQ9XTCB9xb62LyXT7v7uE5UuBsAmKm6Ki9bTA37zz+6p1jCoswfiMF9YEfCmzmyzMhRqyI"
    "5LNBRTMLJsYGxpLQqqu5blcgiMj7SZXYyb2oHJNDRSXR1AWT+b/4SB/Y9Dq6JyXHVRCltVwmew"
    "zr/bkyzmF6b0H4ypgdZMUdQoycLq9HrRgSwdqMRzQVwqwuSS54HoFnUvN1D7elpK7WCYA2teNv"
    "zcBTUHP4+uWnNiNqn8BsJavlzao0xcy2nIBJJPivBdfzt3hbCpxl7u2SeZRT/FMgbu9DnhRlv6"
    "QLQCRuyfTtTAlemVSHwCaiZcLRBQ3C4IKvwOGN8bCqd9wGsJuxP5ln/F4IkDstIsm4RGojLGsj"
    "CKv29TZA0mcUuAsiSBJNdNCtAVUFaEjsmTzmb6zQ7PAVCMHrF0hKuh6qwd0xz8NFBsHuGvKBo/"
    "ODFkuHr7LiFNt3bi9aWQpYE8fqzp2zJPp9YFE0pi7zbB8ToaO3b0FwLuCT91IpPi2LrQ/iZK2U"
    "rpYKmK3LzQltNP42xfe2lZtVDiCaYNc4I3cKp4NPNDUgeLtKHc7LixXRP4V3Q6qFYjp7qWerEb"
    "wqtvvwRaXwcxcCLCTIQcGFHRI1NlL1pn8n2Amhgu1RUBcUW9pRLhGtOBAAvYyF5wowqKzhN76t"
    "2Ky6JEZecsRYYvtwzjxq1z9pSiA3g9CnRXpogcHmWTJ14iaoYmdQZTMAYSRKDb1gE57L2ow3xM"
    "N34hVy4hlCCHzfU1Ynsz4cxrzeU1dKBQMAYzjV3GoO7UJHFaIvjTLwDGWHYyclMWnOyYBHKv9p"
    "F1d4zqxHQyXD3XWjX0BiiYtA+twP8tEUCCHyqCE0fzTY5jJWgEK6DP1d6NmrQefWVlQCvAhk/v"
    "dbL6joscI/EFSo8PP0Kw+GHFpqPWM3yFiPFPa5SVMF+QUDiRA7o80lVCua1Pn7Vx8iKExtFUs1"
    "UFxg/xiyaXGehxC7nIVIUQu1jbpZmyp6l3MuxdW6r3JgA6stmcOg8jEdugZLz7S/DrSNJFoynS"
    "EMmJrF1DAGdMWEzq7JLNiEHvVMuqNhDGRAZrjiLLWGdojS6ZrCrZCrRPt6hvs1nPP4wwECafRY"
    "l9yZRfMD6wWfQINQRlnrd9qD1n3rWBtDSgFHWttNSdYOUsAtTxDn6iyFepnfbFgH17oGF6HDyi"
    "Mx1rexHb8zf1qW6T11jJGYplvQ6IQXcT+pC2KlhXg1yJAKUV1gOe+uWsKRelKrIisFQJK0wzji"
    "Ym23Nzvs3NffjsjHwR92H3GqL34Fv/NPE33eJG3Vkhx4LxRiz6aSS8GSVWGINThVFhZmVQFW/g"
    "220vgCyinsE9BHBLTCAF6BvCeTOy+kHt8XY+3iWRBeLClnVWCP/wVmqyafdAJMnDUYtcy79BUD"
    "qDQg+5+EClXQxX5EzPie8sAPg3VMHrVGsYMyEyawgQk81xKo//mhLKHurrWJn9kRnow2SZ7ull"
    "T4s/OOkJVxhDJu1rfTr1lcqwtXjkVN80s6ZlfBUqusDRkEZQ4JfyObHnVKpXcS9ZoVyLqKyyKQ"
    "DHmDfnvU2n25faObsDUiSuaoRMtAR7KczoBZjVIf7mkCjogPrbpqD5Yq4S2kUnDiU4sGtmqLni"
    "OG5Q2z/wgFp1SXMJrDJ8orU6uNTdsoaS5arohDAQgAgQARklrBQ8mo8UQRA0";

}  // namespace

#endif  // CHROMEOS_ASH_COMPONENTS_CARRIER_LOCK_PSM_CLAIM_VERIFIER_UNITTEST_H_
